@@ -1,5 +1,5 @@
 package HackaMol::PeriodicTable;
-$HackaMol::PeriodicTable::VERSION = '0.037';
+$HackaMol::PeriodicTable::VERSION = '0.038';
 #ABSTRACT: package for period table data... needs to change
 use 5.008;
 require Exporter;
@@ -527,7 +527,7 @@ $KNOWN_NAMES{$_} = 'H' foreach qw(H H1 H2 H3 H4 HA HA1 HA2 HB HB1 HB2 HB3 HD1 HD
                                  HH21 HH22 HN HT1 HT2 HT3 HZ HZ1 HZ2 HZ3
                                  DUM); 
 $KNOWN_NAMES{$_} = 'N' foreach qw(N ND1 ND2 NE NE1 NE2 NH1 NH2 NZ);
-$KNOWN_NAMES{$_} = 'O' foreach qw(O OD1 OD2 OE1 OE2 OG OG1 OH OT1 OT2 OH2);
+$KNOWN_NAMES{$_} = 'O' foreach qw(O OD1 OD2 OE1 OE2 OG OG1 OH OT1 OT2 OH2 OXT);
 $KNOWN_NAMES{$_} = 'S' foreach qw(S SD SG);
 $KNOWN_NAMES{$_} = 'Cl' foreach qw(CLA);
 $KNOWN_NAMES{$_} = 'Na' foreach qw(SOD);
@@ -562,6 +562,7 @@ sub _element_name {
 #carp "$name doesn not exist in HackaMol::PeriodicTable, if common please add to KNOWN_NAMES";
         $dirt = 1;
         my $symbol = substr $name, 0, 1; #doesn't work if two letters for symbol
+        $symbol = 'C' if ($symbol eq 'A');
         return ( $symbol, $dirt );
     }
     return ( $KNOWN_NAMES{$name}, $dirt );
@@ -580,7 +581,7 @@ HackaMol::PeriodicTable - package for period table data... needs to change
 
 =head1 VERSION
 
-version 0.037
+version 0.038
 
 =head1 EXTENDS
 
