@@ -1,5 +1,5 @@
 package HackaMol::Roles::MolReadRole;
-$HackaMol::Roles::MolReadRole::VERSION = '0.037';
+$HackaMol::Roles::MolReadRole::VERSION = '0.038';
 # ABSTRACT: Read files with molecular information
 use Moose::Role;
 use Carp;
@@ -20,7 +20,7 @@ with qw(
 
 has 'hush_read' => (
     is      => 'rw',
-    isa     => 'Bool',
+    isa     => 'Int',
     lazy    => 1,
     default => 0,
 );
@@ -103,7 +103,7 @@ HackaMol::Roles::MolReadRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.037
+version 0.038
 
 =head1 SYNOPSIS
 
@@ -156,7 +156,8 @@ returns a list of HackaMol::Atom objects
 
 =head2 hush_read
 
-isa Bool that is lazy. $hack->hush_read(1) will quiet some warnings that may be ignored under some instances.
+isa Int that is lazy (default 0). $hack->hush_read(1) will quiet some warnings that may be ignored under some instances. 
+$hack->hush_read(-1) will increase info printed out for some warnings.
 
 =head1 SEE ALSO
 
