@@ -1,5 +1,5 @@
 package HackaMol::Roles::PdbRole;
-$HackaMol::Roles::PdbRole::VERSION = '0.037';
+$HackaMol::Roles::PdbRole::VERSION = '0.038';
 #ABSTRACT: PdbRole of lazy attributes for HackaMol atoms
 use Moose::Role;
 use Carp;
@@ -33,6 +33,7 @@ has 'segid',       is => 'rw', isa => 'Str', lazy => 1, default => ' ';
 has 'iatom',       is => 'rw', isa => 'Int', lazy => 1, default => 0;
 has 'resid',       is => 'rw', isa => 'Int', lazy => 1, default => 1;
 has 'serial',      is => 'rw', isa => 'Int', lazy => 1, default => 1;
+has 'sasa',        is => 'rw', isa => 'Num', lazy => 1, default => 0.0;
 
 #lifted from Bio::PDB::Structure::Atom. Thank you, Raul Alcantara Aragon!
 
@@ -238,7 +239,7 @@ HackaMol::Roles::PdbRole - PdbRole of lazy attributes for HackaMol atoms
 
 =head1 VERSION
 
-version 0.037
+version 0.038
 
 =head1 SYNOPSIS
 
@@ -336,6 +337,10 @@ a CHARMMish parameter that may not belong here. default = 'TIP3'
 this is a place for the actual index.  Segid does not have to start from 0 (cut
 and paste as above, etc). 
 
+=head2 sasa        
+
+Solvent accessible surface area; isa 'Num'. A place for storing results from such calculations.  
+
 =head1 SEE ALSO
 
 =over 4
