@@ -1,9 +1,9 @@
 package HackaMol::Roles::ReadPdbRole;
-$HackaMol::Roles::ReadPdbRole::VERSION = '0.037';
+$HackaMol::Roles::ReadPdbRole::VERSION = '0.038';
 # ABSTRACT: Read files with molecular information
 use Moo::Role;
 use strictures 2;
-use HackaMol::PeriodicTable qw(%KNOWN_NAMES _element_name _trim _qstring_num);
+use HackaMol::PeriodicTable qw(_element_name _trim _qstring_num);
 use Math::Vector::Real;
 use Carp;
 
@@ -38,7 +38,7 @@ sub read_pdb_atoms {
                 $resName,     $chainID, $resSeq,  $icod,
                 $x,           $y,       $z,       $occ,
                 $B,           $segID,   $element, $charge
-            ) = unpack "A6A5x1A4A1A3x1A1A4A1x3A8A8A8A6A6x6A4A2A2", $_;
+            ) = unpack "A6A5x1A4A1A3x1A1A4A1x3A8A8A8A6A6x6A4A2A2", $_ . (" " x 12); # padded out to accommodate truncated pdbs
 
             if   ( $charge =~ m/\d/ ) { $charge = _qstring_num($charge) }
             else                      { $charge = 0 }
@@ -104,9 +104,14 @@ sub read_pdb_atoms {
     # set iatom to track the array.  diff from serial which refers to pdb
     $atoms[$_]->iatom($_) foreach ( 0 .. $#atoms );
     if ($something_dirty) {
-        unless ( $self->hush_read ) {
+        if ( $self->hush_read <= 0 ) {
             my $message = "MolReadRole> found $something_dirty dirty atoms. ";
-            $message .= "Check symbols and lookup names";
+            $message .= "Check symbols and lookup names PeriodicTable.pm:";
+            my @sprintf;
+            foreach my $atom (grep {$_->is_dirty} @atoms){
+              push @sprintf, sprintf(" DIRTY: index %s name %s element %s %10.3f %10.3f %10.3f;", $atom->iatom, $atom->name, $atom->symbol, @{$atom->xyz});
+            }
+            $message .= $_ foreach @sprintf;
             carp $message;
         }
     }
@@ -125,7 +130,7 @@ HackaMol::Roles::ReadPdbRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.037
+version 0.038
 
 =head1 SYNOPSIS
 
@@ -149,9 +154,10 @@ According to the PDB specification, the element symbol should be present in colu
 77-78.  The element is often ommitted by programs, such as charmm, that can write 
 pdbs because it makes the file larger, and the information is accessible somewhere 
 else (protein structure file). Unfortunately, other programs require the information.  
-HackaMol::MolReadRole, loads a hash (KNOWN_NAMES) from HackaMol::PeriodicTable 
-that maps common names to the element (e.g. POT => 'K'). read_pdb_atoms will carp if 
-the name is not in the hash, and then set the element to the first letter of the name. 
+HackaMol::MolReadRole, uses HackaMol::PeriodicTable to map common names to the element 
+(e.g. POT => 'K'). read_pdb_atoms will carp if the name is not in the hash, and then 
+set the element to the first letter of the name. If you see one of these messages for 
+a common atom, please submit an issue or pull request so the atom can be added!
 
 =head1 SEE ALSO
 
