@@ -1,9 +1,9 @@
 package HackaMol::Roles::ReadPdbqtRole;
-$HackaMol::Roles::ReadPdbqtRole::VERSION = '0.037';
+$HackaMol::Roles::ReadPdbqtRole::VERSION = '0.038';
 # ABSTRACT: Read files with molecular information
 use Moo::Role;
 use strictures 2;
-use HackaMol::PeriodicTable qw(%KNOWN_NAMES _element_name _trim _qstring_num);
+use HackaMol::PeriodicTable qw(_element_name _trim _qstring_num);
 use Math::Vector::Real;
 use Carp;
 
@@ -62,7 +62,6 @@ sub read_pdbqt_atoms {
             $ADTtype = _trim($ADTtype);
 
             my ( $element, $qdirt ) = _element_name($ADTtype);
-            $element = 'C' if ( $element eq 'A' );    #aromatic, is this dirty?
             $something_dirty++ if ($qdirt);
             my $xyz = V( $x, $y, $z );
 
@@ -130,7 +129,7 @@ HackaMol::Roles::ReadPdbqtRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.037
+version 0.038
 
 =head1 SYNOPSIS
 
